@@ -5,6 +5,8 @@
 
 use std::fmt;
 
+use serde_json as json;
+
 use super::*;
 
 impl Error {
@@ -31,6 +33,39 @@ impl Error {
     pub fn state_already_exists(&self) -> bool {
         self.error_code == STATE_ALREADY_EXISTS
     }
+
+    pub fn unknown_error(status: http::StatusCode, bytes: &[u8]) -> Self {
+        let http_code = status.as_u16();
+        let http_status = status
+            .canonical_reason()
+            .unwrap_or_else(|| status.as_str())
+            .to_string();
+
+        let (error_code, msg, request_id) = match json::from_slice::<json::Value>(bytes) {
+            Ok(ref value) => (
+                get(value, "errorCode"),
+                get(value, "msg"),
+                get(value, "requestId"),
+            ),
+            Err(e) => {
+                let msg = format!("{e}\nCheck your config file (~/.statehub/config.toml by default) for valid api server url");
+                (None, Some(msg), None)
+            }
+        };
+        let error_code = error_code.unwrap_or_else(|| http_status.clone());
+
+        Self {
+            http_code,
+            http_status,
+            error_code,
+            msg,
+            request_id,
+        }
+    }
+}
+
+fn get(value: &json::Value, index: &str) -> Option<String> {
+    value.get(index)?.as_str().map(String::from)
 }
 
 impl fmt::Display for Error {
